<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/TR/WD-xsl">

<!--
   +==========================================================================+
   | Copyright 2002, 2003 Rational Software Corporation.  All Rights Reserved.|
   | This software contains proprietary and confidential information of       |
   | Rational and its suppliers.  Use, disclosure or reproduction is          |
   | prohibited without the prior express written consent of Rational.        |
   +==========================================================================+
-->

<!-- ********************************************************************
     Id: ccexpl_infopane.xsl

     Together with ccexpl_infopane.htm, this style sheet provides and 
     formats content for the Rational ClearCase Explorer's Information Pane.

     Copyright 2002 Rational Software Corporation.  All Rights Reserved.
     ******************************************************************** -->


<xsl:template match="/">

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
     Detect multiple or no selection.
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

<xsl:for-each select='items'>

  <xsl:choose> 

    <xsl:when test="item/@type[.='nothing']">

      <DIV CLASS="divindent">

      <xsl:choose>

        <xsl:when test="item/ucm[.='1']"> <!-- UCM views -->

          <xsl:choose>                

            <xsl:when test="item/integration[.='1']"> <!-- UCM integration views -->

                <xsl:choose>                

                    <xsl:when test="item/snapshot[.='1']">


<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     UCM Snapshot Integration View - static page
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->


<P STYLE="font-size: 10pt; font-weight: bold; color: #000080">UCM Snapshot Integration View</P>

<P> This is your view in the <xsl:value-of select='item/projectname'/> project's integration stream. 
The integration stream identifies the shared versions to be used to build and test
the project. The shared versions are delivered from all the project's
development views. </P>

<P>If you are a developer, use the integration view to see the
work other team members have delivered, and to test your own work during 
delivery.</P>

<P>If you are a project manager, use the integration view to:</P>

<UL>

<LI><P>Create new baselines as development proceeds. Developers can then rebase to the new baselines to stay current with project changes.</P></LI>

<LI><P>Promote or demote baselines. The promotion level indicates the quality and stability of the
baseline to all developers.</P></LI>

<LI><P>Provide assistance to developers
who need help completing deliveries.</P></LI>

</UL>

<P>To copy a set of of source files into your view, use the <STRONG>Update</STRONG> command.</P>

<P><STRONG>Note: </STRONG>A snapshot view is not automatically updated. 
To see changes to the stream, you should update the view periodically 
by clicking <STRONG>Environment &#8594; Update View</STRONG> in the ClearCase Explorer menu.</P>

                    
                    </xsl:when>

                    <xsl:otherwise>

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     UCM Dynamic Integration View - static page
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->


<P STYLE="font-size: 10pt; font-weight: bold; color: #000080">UCM Dynamic Integration View</P>

<P> This is an integration view for the <xsl:value-of select='item/projectname'/> project.</P>

<P>An integration stream identifies the shared versions to be used to build and test
either the entire project, or a major feature of the project. The shared versions are delivered from 
child integration or development streams below it in the project hierarchy. </P>

<P>If you are a developer, use this view to see the work other team members have delivered, 
and to test your own work during delivery.</P>

<P>If you are a project manager, use the integration view to:</P>

<UL>

<LI><P>Create new baselines as development proceeds. Developers can then rebase to the new baselines to stay current with project changes.</P></LI>

<LI><P>Promote or demote baselines. The promotion level indicates the quality and stability of the baseline to all developers.</P></LI>

<LI><P>Provide assistance to developers who need help completing deliveries.</P></LI>

</UL>

<P><STRONG>Note: </STRONG>The contents of your view are automatically updated whenever 
a change occurs in the VOB (for example, when a new version is checked in). 
To update your display to include any changes to the stream, 
click <STRONG>View &#8594; Refresh</STRONG> in the ClearCase Explorer menu.</P>


                    </xsl:otherwise>

                </xsl:choose>                

            </xsl:when>

            <xsl:otherwise>    <!-- UCM Development views -->

                <xsl:choose>                

                    <xsl:when test="item/snapshot[.='1']">


<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     UCM Snapshot Development View - static page
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->


<P STYLE="font-size: 10pt; font-weight: bold; color: #000080">UCM Snapshot Development View</P>

<P>This view is your work area for the <xsl:value-of select='item/projectname'/> 
project development stream. In UCM development views, work is focused on activities 
rather than directly on source files. </P>

<P>When you joined the project, your view was initialized with a set of recommended baselines. 
It is the baseline that identifies the activities required to develop one or more project components. 
The baseline also identifes the set of element versions that are judged to be stable for those components.</P>

<P>Periodically, you will rebase your development stream 
to the latest recommended baseline in your parent stream. A rebase operation reconfigures your 
development stream by updating its set of foundation baselines.</P>

<P>To display the activities available in this view, click <STRONG>My Activities</STRONG> 
in the folder pane. Then, set an activity for your view by selecting the check box next 
to the activity. This ensures that any work you perform on the ClearCase elements in your view 
is associated with that activity in your project's development stream.</P>

<P>To copy a set of of source files into your view, use the <STRONG>Update</STRONG> command.</P>

<P><STRONG>Note: </STRONG>A snapshot view is not automatically updated. 
To see changes to the stream, you should update the view periodically by clicking 
<STRONG>Environment &#8594; Update View</STRONG> in the ClearCase Explorer menu.</P>


                    </xsl:when>

                    <xsl:otherwise>

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     UCM Dynamic Development View - static page
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

<P STYLE="font-size: 10pt; font-weight: bold; color: #000080">UCM Dynamic Development View</P>

<P>This view is your work area for the <xsl:value-of select='item/projectname'/> 
project development stream. In a UCM view, your work is always associated with an activity. 
An activity is a ClearCase object that identifies the versions you create to complete a 
development task. Your organization defines the tasks to be performed in activities.</P>

<P>To display the activities available in this view, click <STRONG>My Activities</STRONG> 
in the folder pane. Then, set an activity for your view by selecting the check box next 
to the activity. This ensures that any work you perform on the ClearCase elements in your 
view is associated with that activity in your project's development stream.</P>

<P>Periodically, you will rebase your view 
to the latest baseline. A rebase updates your view with versions that have been integrated, 
tested, and approved for general use.</P>

<P>You deliver completed activities to the project's integration stream, 
where your work becomes available to others in the project.</P>

<P><STRONG>Note: </STRONG>The contents of your view are automatically updated whenever a 
change occurs in the VOB (for example, when a new version is checked in). To update your 
display to see any changes to the stream, click <STRONG>View &#8594; Refresh</STRONG> 
in the ClearCase Explorer menu.</P>


                    </xsl:otherwise>

                </xsl:choose>                

            </xsl:otherwise>

          </xsl:choose>                

        </xsl:when>

        <xsl:otherwise>     <!-- Non-UCM views -->

          <xsl:choose>                

            <xsl:when test="item/snapshot[.='1']"> <!-- Non-UCM Snapshot -->

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     Non-UCM Snapshot View - static page
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->


<P STYLE="font-size: 10pt; font-weight: bold; color: #000080">Snapshot View</P>

<P>Your project's source files are stored in one or more ClearCase data repositories 
called VOBs (versioned object bases). This view allows you to access those files.</P>

<P>Each time you check out, modify, and check a file back in, ClearCase creates a new 
version that records the changes. Version control is just one of the features that enable 
your team to manage changes and coordinate access to sources.</P>

<P>In addition to ClearCase elements, your view can contain view-private objects - 
normal working files and folders that are not stored in a ClearCase VOB. 
To include a view-private file or folder, simply drag it into your view from your 
Windows Explorer.</P>

<P>The ClearCase Explorer shortcut pane, toolbar, and menus provide access to all the 
ClearCase operations you can perform in your view. In addition, you can perform many 
operations using standard Windows functions. For example, double-clicking an HTML element 
performs the associated operation, such as opening the document in your Web browser.</P>

<P>To copy a set of of source files into your view, use the <STRONG>Update</STRONG> command.</P>

<P><STRONG>Note: </STRONG>A snapshot view is not automatically updated. To see changes in the VOB, 
you should update the view periodically by clicking <STRONG>Environment &#8594; Update View</STRONG> 
in the ClearCase Explorer menu.</P>


                        </xsl:when>
                        <xsl:otherwise> <!-- Non-UCM Dynamic -->

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     Non-UCM Dynamic View - static page
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->


<P STYLE="font-size: 10pt; font-weight: bold; color: #000080">Dynamic View</P>

<P>Your project's source files are stored in one or more ClearCase data repositories 
called VOBs (versioned object bases). This view allows you to access those source files.</P>

<P>Each time you check out, modify, and check a file back in, ClearCase creates a new 
version that records the changes. Version control is just one of the features that 
enable your team to manage changes and coordinate access to sources.</P>

<P>In addition to ClearCase elements, your view can contain view-private objects - normal 
working files and folders that are not stored in a ClearCase VOB. To include a view-private 
file or folder, simply drag it into your view from your Windows Explorer. </P>

<P>The ClearCase Explorer shortcut pane, toolbar, and menus provide access to all the ClearCase 
operations you can perform in your view. In addition, you can perform many operations using 
standard Windows functions. For example, double-clicking an HTML element performs the associated 
operation, such as opening the document in your Web browser.</P>

<P><STRONG>Note: </STRONG>Because this is a dynamic view, the contents of your view are 
automatically updated whenever a change occurs in the VOB (for example, when a new element or 
version is created). To update your display to see any changes to the VOB, click 
<STRONG>View &#8594; Refresh</STRONG> in the ClearCase Explorer menu.</P>

                        </xsl:otherwise>
 
                    </xsl:choose>                

                </xsl:otherwise>

            </xsl:choose>

        </DIV>

        </xsl:when>

        <xsl:otherwise> <!-- Handle multiple selections -->

            <xsl:apply-templates select='.'/>

        </xsl:otherwise>

    </xsl:choose>

</xsl:for-each>

</xsl:template>


<xsl:template match='items'> <!-- Process a single selection -->


<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     Wrapper table containing title, navigation tabs, and two nested tables
     +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

    <TABLE BORDER="0" CELLSPACING="0" CELLPADDING="0" WIDTH="100%">

        <TR>

            <TD HEIGHT="20" VALIGN="MIDDLE" BGCOLOR="#C0C0C0" STYLE="font-size: 10pt; font-weight: bold; color: #000080">

                <IMG ALIGN="ABSMIDDLE" SRC="object.gif" BORDER="0" 
                ALT="Use the View menu to hide or display the Information Pane. 
                Drag horizontal and vertical dividers to resize." />&#160;Your selection&#160;&#160;&#160;


            </TD>
 
            <TD NOWRAP="NOWRAP" VALIGN="BOTTOM" ALIGN="LEFT" STYLE="background-color: #C0C0C0">&#160;&#160;&#160;

                <SPAN STYLE="cursor: hand"  ONCLICK="change_abouttab();">

                    <IMG NAME="image1" SRC="abouttab-on.gif" ALT="Information about your selection" WIDTH="71" HEIGHT="12" BORDER="0" ALIGN="ABSBOTTOM"/>

                </SPAN>

                <SPAN STYLE="cursor: hand" ONCLICK="change_usestab();">

                    <IMG NAME="image2" SRC="usestab-off.gif" ALT="Things you can do with your selection" WIDTH="71" HEIGHT="12" BORDER="0" ALIGN="ABSBOTTOM"/>

                </SPAN>

            </TD>

        </TR>


        <TR>

            <TD VALIGN="TOP" ALIGN="LEFT" WIDTH="230">


    <!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
         Nested left table listing properties of selected item
         +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

    <TABLE BORDER="0" CELLSPACING="5" WIDTH="230" STYLE="border-top: none; border-right: 1px #000080 solid; border-bottom: none; border-left: none;">

        <xsl:for-each select = 'item'>

<!-- 
            <TR>
                <SPAN TITLE="The class of ClearCase element - either file, folder, or activity">
                    <TH WIDTH="80" ALIGN="LEFT" >Element&#160;Type:</TH>
                </SPAN>                 
                <TD>
                <xsl:choose>
                    <xsl:when test="@type[.='folder']">
                        Folder
                    </xsl:when>
                    <xsl:when test="@type[.='activity']">
                        Activity
                    </xsl:when>
                    <xsl:otherwise> 
                        File
                    </xsl:otherwise>
                </xsl:choose>
                </TD>
            </TR>
-->

            <xsl:if test="name[.!='']">

            <TR>

                <SPAN TITLE="The element name in ClearCase">

                    <TH WIDTH="80"  ALIGN="LEFT" >Name:</TH>

                </SPAN> 

                <TD>

                    <xsl:value-of select='name'/>

                </TD>

            </TR>

            </xsl:if>


            <xsl:if test="viewtag[.!='']">

            <TR>

                <SPAN TITLE = "The qualified name of the view in ClearCase">

                    <TH WIDTH="80"  ALIGN="LEFT" >View Tag:</TH>

                </SPAN>                 

                <TD>

                    <xsl:for-each select='viewtag'>

                        <xsl:eval>break_line(this)</xsl:eval>

                    </xsl:for-each>

                </TD>

            </TR>

            </xsl:if>


            <xsl:if test="viewpath[.!='']">

            <TR>

                <SPAN TITLE = "The folder where you can work on view files">

                    <TH WIDTH="80"  ALIGN="LEFT" >View&#160;Path:</TH>

                </SPAN>                 

                <TD>

                    <xsl:for-each select='viewpath'>

                        <xsl:eval>break_line(this)</xsl:eval>

                    </xsl:for-each>

                </TD>                

            </TR>

            </xsl:if>


<!-- Type covered in 'about' tab, omit here. -->

        <xsl:if test="ucm[.='1']">

            <TR>

                <SPAN TITLE = "The project you are currently working in">

                    <TH WIDTH="80"  ALIGN="LEFT" >UCM&#160;Project:</TH>

                </SPAN> 
                
                <TD>

                    <xsl:value-of select='projectname'/>

                </TD>

            </TR>

        <!-- UCM integration covered in 'about' tab, omit here. -->

        </xsl:if>


<!-- Full Path not needed -->

        <xsl:if test="activityset[.!='0']">

          <TR><TD HEIGHT="15"><P>&#10;</P></TD></TR>

        </xsl:if>


        <xsl:if test="cqonlyactivity[.!='0']">

          <TR><TD HEIGHT="15"><P>&#10;</P></TD></TR>

        </xsl:if>


        <xsl:if test="state[.!='']">

          <TR>

            <SPAN TITLE = "Current, changeable status of an element">

              <TH WIDTH="80"  ALIGN="LEFT" >State: </TH>

            </SPAN>                 

            <TD>

              <xsl:value-of select='state'/>

            </TD>                

          </TR>

        </xsl:if>


        <xsl:if test="kind[.!='']">

          <TR>

            <SPAN TITLE = "Kind of ClearCase object">

              <TH WIDTH="80"  ALIGN="LEFT" >Kind: </TH>

            </SPAN> 
   
            <TD>

              <xsl:value-of select='kind'/>

            </TD>
                
          </TR>

        </xsl:if>


        <xsl:if test="modified[.!='']">

          <TR>

            <SPAN TITLE = "The last date the element was changed">

              <TH WIDTH="80"  ALIGN="LEFT" >Modified: </TH>

            </SPAN> 
    
            <TD>

              <xsl:value-of select='modified'/>

            </TD>                

          </TR>

        </xsl:if>


        <xsl:if test='(kind[.!="View-private Directory"])'>

            <xsl:if test='(kind[.!="View-private File"])'> 

                <xsl:if test="version[.!='']">

                    <TR>

                        <SPAN TITLE = "The version of the element">

                            <TH WIDTH="80"  ALIGN="LEFT" >Version: </TH>

                        </SPAN> 
                
                        <TD>

                            <xsl:value-of select='version'/>

                        </TD>                

                    </TR>

                </xsl:if>

            </xsl:if>

        </xsl:if>

    <!--  annotations not needed here -->

        <xsl:if test='(kind[.!="View-private Directory"])'>

            <xsl:if test='(kind[.!="View-private File"])'>

                <xsl:if test="rule[.!='']">

                    <TR>

                        <SPAN TITLE = "Config spec rules that apply to this element">

                            <TH WIDTH="80"  ALIGN="LEFT" >Rule: </TH>

                        </SPAN> 

                        <TD>

                            <xsl:value-of select='rule'/>

                        </TD>                

                    </TR>

                </xsl:if>

            </xsl:if>

        </xsl:if>

      </xsl:for-each>

   </TABLE>

 <!-- end nested left table -->

</TD>

<TD VALIGN="TOP">

    <!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

    <!--     Begin nested right table describing selected item                                        -->

    <!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

    <TABLE BORDER="0" CELLSPACING="5" WIDTH="100%" ALIGN="TOP">

        <TR>

            <TD>

    <!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

    <!--     Content for 'about' tab                                                                    -->

    <!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

                <DIV ID="elemAbout" STYLE="position:absolute, top:0; left:0">

                    <!-- element type -->

                    <xsl:choose>

                        <xsl:when test="item/@type[.='folder']">

                            <xsl:choose>

                                <xsl:when test="(item/name[.='lost+found'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold">

                                    <xsl:value-of select='item/name'/></EM>

                                     is a folder that ClearCase creates in the top level of each VOB in your view.</P>

                                    <P>ClearCase uses it to store orphaned elements (elements that are no longer cataloged in any version in the VOB).</P>

                                </xsl:when>


                                <xsl:when expr="parent_dir(this,'lost+found')">        

                                    <P>This item is an orphan folder that was once under version control. ClearCase has moved it here because no version of the folder exists in any VOB.</P>

                                    <P>ClearCase appends a unique hexadecimal id number to the original folder name.</P>

                                </xsl:when>


                                <xsl:when test="(item/kind[.='View-private Directory'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold">

                                    <xsl:value-of select='item/name'/></EM> is a view-private folder. This means that it has no representation in a ClearCase VOB: even though it is in your view's working folder, this folder and all its contents exist only in your file system. </P>

                                </xsl:when>

        
                                <xsl:when test="(item/kind[.='Directory Version'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold">

                                    <xsl:value-of select='item/name'/></EM> is a versioned folder. Its attributes and contents are under ClearCase control. </P>

                                </xsl:when>


                                <xsl:when test="(item/kind[.='Directory Element'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold">

                                    <xsl:value-of select='item/name'/></EM> is a folder under ClearCase control. </P>

                                </xsl:when>


                                <xsl:when test="(item/kind[.='VOB Symbolic Link'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select='item/name'/></EM> is not an element, but a reference to a target folder in a different location. </P><P>VOB symbolic links, also called symlinks, behave similarly to UNIX symbol links. </P>

                                </xsl:when>

                                <xsl:otherwise>

                                    <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select='item/name'/></EM> is a VOB (versioned object base). This is the data repository for all the versions of a set of files and directories that you maintain under ClearCase control. </P><P>For more information, see About VOBs in the main help. To open the main help for Rational ClearCase, click <b>Start > Programs > IBM Rational > IBM Rational ClearCase > Online help</b>, and then look under <b>Developing software with Rational ClearCase</b></P>

                                </xsl:otherwise>

                            </xsl:choose>

                        </xsl:when>


                        <xsl:when test="item/@type[.='activity']">

                            <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select='item/name'/></EM> is a UCM activity.</P>

                            <P>An activity records a set of versions that you create for a development task. </P>

                        </xsl:when>


                        <xsl:otherwise> <!-- default is 'file' -->

                            <xsl:choose>

                                <xsl:when expr="parent_dir(this,'lost+found')">        

                                    <P>This item is an orphan element. ClearCase has moved it here from another folder because no version of the element exists in any VOB.</P>

                                    <P>ClearCase appends a unique hexadecimal id number to the original element name.</P>

                                </xsl:when>


                                <xsl:when test="(item/kind[.='View-private File'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select='item/name'/></EM> is 

                                    a view-private file not under ClearCase source control.</P>

                                </xsl:when>

        
                                <xsl:when test="(item/kind[.='VOB Symbolic Link'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select='item/name'/></EM> is 

                                    not an element, but a reference to a target file in a different location. </P><P>VOB symbolic links, also called symlinks, behave similarly to UNIX symbol links.</P>

                                </xsl:when>


                                <xsl:when test="(item/kind[.='File'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select='item/name'/></EM> is 

                                    a configuration file created by ClearCase.</P>

                                </xsl:when>


                               <xsl:when test="(item/kind[.='Derived Object Version'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select='item/name'/></EM> is 

                                    a file produced by a clearmake or omake build or a clearaudit session.</P>

                               </xsl:when>


                               <xsl:when test="(item/kind[.='View Derived Object'])">            

                                    <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select='item/name'/></EM> is 

                                    a file produced by a clearmake or omake build or a clearaudit session.</P>

                                </xsl:when>

                                <xsl:otherwise>

                                    <P><EM STYLE="font-style: normal; font-weight: bold"><xsl:value-of select='item/name'/></EM> is 

                                    a versioned file under ClearCase source control.</P>

                                </xsl:otherwise>

                            </xsl:choose>

                        </xsl:otherwise>

                    </xsl:choose>


                    <!-- states -->

                    <xsl:if test="item/state[.='Checked Out (Reserved)']">

                        <P>You currently have <xsl:value-of select='item/name'/> checked out. You also have it reserved, so that only you can create the next version.</P>

                    </xsl:if>

                    <xsl:if test="item/state[.='Checked Out (Unreserved)']">

                        <P>You currently have <xsl:value-of select='item/name'/> checked out but not reserved. This means that anyone else can also check out the element.</P>

                    </xsl:if>


                    <xsl:if test="item/state[.='Hijacked']">

                        <P>This item is currently hijacked: it has been modified without being checked out. Hijacking takes a file outside of direct ClearCase control. </P>

                        <P>For more information, see About hijacked files in the main help. To open the main help for Rational ClearCase, click <b>Start > Programs > IBM Rational > IBM Rational ClearCase > Online help</b>, and then look under <b>Developing software with Rational ClearCase</b></P>

                        <P>For brief information about how to correct the problem, click the Uses tab.</P>

                    </xsl:if>

                    <!-- activityset -->

                    <xsl:if test="item/activityset[.='1']">

                      <p>This is the current activity in your stream.</p>

                    </xsl:if>

                    <!-- cqonlyactivity -->

                    <xsl:if test="item/cqonlyactivity[.='1']">

                      <p>This ClearTeam item is not a UCM activity, because it has not been checked out in the current stream.</p>

                    </xsl:if>


                    <!-- annotations -->

                    <xsl:choose>

                        <xsl:when test="item/annotations[.='test']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>Here's an annotation. In some cases, suggest a user action.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='eclipsed']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>This element is eclipsed. No version of the element is selected because a view-private object with the same name exists in your view.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='checkedout but eclipsed']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element has been checked out in this view, but there is no CHECKEDOUT config spec rule; thus, the checked-out version is not visible in the view.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='not loaded, checkedout but removed']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element was checked out in this view, but the view-private file was subsequently removed.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='no version selected']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is not selected by any config spec rule, or is selected by a -none config spec rule.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='error on reference']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is selected by an -error config spec rule.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='no config record ']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The derived object's data container is still stored in the view, but the derived object in the VOB database has been deleted.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='disputed checkout']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is considered to be checked out by the view server but is not so indicated in the VOB database.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='removed with white out']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The derived object was winked in by, and is still referenced by, the current view, but it has been removed from the VOB database.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='not loaded']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is not loaded into the snapshot view.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='loaded but missing']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>A version of the element was loaded into the view, but the file has been deleted or renamed in the view.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='hijacked']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>This version has been hijacked. It has been modified without being checked out.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='overridden']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is loaded in the snapshot view, but its file type is not the same as the corresponding object in the VOB; or the element is not loaded in the snapshot view, but an object with the same name exists in the view.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='special selection']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The version you checked in is not the version that the config spec selects from the VOB.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='nocheckout']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The version hijacked in the view is no longer the version the config spec selects from the VOB.</P>

                        </xsl:when>


                        <xsl:when test="item/annotations[.='deleted version']">

                                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The version currently in the view has been removed from the VOB.</P>

                        </xsl:when>

                    </xsl:choose>

                </DIV>


    <!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

    <!--     Content for 'uses' tab                                                                   -->

    <!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

                <DIV STYLE="position: relative; left: 0; display: none" ID="elemUses" >

                        <xsl:apply-templates select='item'/>

                </DIV>

            </TD>

        </TR>

    </TABLE>

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

<!--     End nested right table                                                                     -->

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->


</TD></TR></TABLE>

</xsl:template>


<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

<!--     Template for doing things with item types in the 'uses' tab                              -->

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

<xsl:template match='item'>

    <xsl:choose> <!-- element type -->

        <xsl:when test="@type[.='folder']">

            <xsl:choose>

                <xsl:when test="(name[.='lost+found'])">            

                    <P>You cannot check out and should not delete this folder, although you can add files to it.</P>

                    <P>You should periodically check this folder's contents after updating or refreshing your view, clean it up to conserve disk space. </P>

                    <P>Elements in the lost+found folder can be moved to versioned folders, or deleted.</P>

                </xsl:when>


                <xsl:when expr="parent_dir(this,'lost+found')">        

                    <P>An orphan folder is similar to a view-private folder in that you cannot check it out. Consider the following options:</P>

                    <UL>

                        <LI><P>If you need this folder or its elements, you can bring it under version control by moving it to a versioned part of your view, or relocating it to another VOB.</P></LI>

                        <LI><P>If you own the folder or have sufficient permissions, you can delete it.</P></LI>

                    </UL>

                </xsl:when>


                <xsl:when test="(kind[.='View-private Directory'])">            

                    <P>Use this folder just as you would any folder in your file system. For example, you can access it directly in Windows Explorer.</P>

                    <P>You can add this folder to ClearCase source control at any time.</P>

                </xsl:when>

        
                <xsl:when test="(kind[.='Directory Version'])">            

                    <P>ClearCase manages this folder for you. For example, when you modify a folder by creating or deleting elements within it, ClearCase automatically checks the folder out and back in for you.</P>

                </xsl:when>

                <xsl:when test="(kind[.='Directory Element'])"></xsl:when>


                <xsl:when test="(kind[.='VOB Symbolic Link'])">            

                    <P>You cannot check out the elements in a symlink folder; you can only access the targets that the elements refer to. For more information see the main help. To open the main help for Rational ClearCase, click <b>Start > Programs > IBM Rational > IBM Rational ClearCase > Online help</b>, and then look under <b>Developing software with Rational ClearCase</b>, and search for VOB links.</P>

                    <P>You cannot delete a symlink unless you are the owner or have sufficient permissions.</P>

                </xsl:when>

                <xsl:otherwise>

                    <P>Expand the VOB in the folder pane to navigate the directories that are loaded in your view. </P>

                </xsl:otherwise>

            </xsl:choose>

        </xsl:when>


        <xsl:when test="@type[.='activity']">

            <P>To start working on an activity, you first set the activity for your view by selecting the check box next to the activity.</P>

            <P>Thereafter, when you check out files to work on them, this activity will be set for you in the checkout dialog box Activity list.</P>

            <P>When your work on this activity is ready, you will deliver it to the project's integration stream.</P>

        </xsl:when>


        <xsl:otherwise> <!-- default is 'file' -->

            <xsl:choose>

                <xsl:when expr="parent_dir(this,'lost+found')">        

                    <P>An orphan file is similar to a view-private file in that you cannot check it out. Consider the following options:</P>

                    <UL>

                        <LI><P>If you need this file, you can bring it under version control by moving it to a versioned folder in your view, or relocating it to another VOB.</P></LI>

                        <LI><P>If you own the file or have sufficient permissions, you can delete it.</P></LI>

                    </UL>

                </xsl:when>


                <xsl:when test="(kind[.='View-private File'])">            

                    <P>Use this file just as you would any file in your file system. For example, you can access it directly in Windows Explorer or in an application.</P>

                    <P>You can add this file to ClearCase source control at any time.</P>

                </xsl:when>


                <xsl:when test="(kind[.='VOB Symbolic Link'])">            

                    <P>You cannot check out a symlink; you can only access the element that it refers to. For more information see the main help. To open the main help for Rational ClearCase, click <b>Start > Programs > IBM Rational > IBM Rational ClearCase > Online help</b>, and then look under <b>Developing software with Rational ClearCase</b>, and search for VOB links.</P>

                    <P>You cannot delete a symlink unless you are the owner or have sufficient permissions.</P>

                </xsl:when>


                <xsl:when test="(kind[.='File'])">            

                    <P>You should not check out or modify this file.</P>

                </xsl:when>


                <xsl:when test="(kind[.='File Element Version'])">

                    <xsl:choose>

                        <xsl:when test="(state[.='Hijacked'])">            

                            <P>Right-click the item and select <b>Undo Hijacked File</b> in the shortcut menu.  </P>

                            <P>When you undo a hijacked file, ClearCase renames the hijacked file with a new extension, .keep, and loads the version that your view selects from the VOB. </P>

                        </xsl:when>

                        <xsl:otherwise>

                            <P>To work on a versioned file, you check it out: right-click the element in the Details pane and select <STRONG>Check Out...</STRONG> in the shortcut menu. ClearCase creates a private copy for you to work on in your view.</P>

                            <P>After revising the file, you should check it back in to store a new version in the VOB.</P>

                        </xsl:otherwise>

                    </xsl:choose>

                </xsl:when>


                <xsl:when test="(kind[.='Derived Object Version'])">            

                    <P>Each derived object is associated with the configuration record that is created by the ClearCase build program to document the build. </P>

                </xsl:when>

                <xsl:when test="(kind[.='View Derived Object'])">            

                    <P>Each derived object is associated with the configuration record that is created by the ClearCase build program to document the build. A shareable DO can be winked in by other views. A nonshareable DO cannot be winked in by other views unless you explicitly make it available. </P>

                </xsl:when>


                <xsl:when test="(state[.='Checked Out (Reserved)'])">

                    <P>You have exclusive rights to modify this file and check in a new version.</P>

                    <P>When you are ready to save your work in ClearCase, check the file in.</P>

                    <P>If you decide not to create a new version, you can cancel your checkout at any time.</P>

                </xsl:when>


                <xsl:when test="(state[.='Checked Out (Unreserved)'])">

                    <P>Because your checkout is not reserved, other people may also have it checked out. If so, the first person to check in the page creates the new version. Everyone else must merge the latest version into their own work before they can check in their changes.</P>

                    <P>When you are ready to save your work in ClearCase, check the file in.</P>

                    <P>If you decide not to create a new version, you can cancel your checkout at any time.</P>

                </xsl:when>

                <xsl:otherwise>

                   <P>Unspecified condition</P>

                </xsl:otherwise>

            </xsl:choose>

        </xsl:otherwise>

    </xsl:choose>

    <xsl:choose> <!-- annotations -->

        <xsl:when test="annotations[.='eclipsed']">

                <P>To fix the eclipsed condition, delete or move the view-private element from your view. Then, click <STRONG>View &#8594; Refresh</STRONG>.</P>

        </xsl:when>


        <xsl:when test="annotations[.='loaded but missing']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>To fix the loaded but missing condition, restore the missing file or unload it from the view.</P>

        </xsl:when>


        <xsl:when test="annotations[.='checkedout but eclipsed']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>To fix the checkdout but eclipsed condition, add a CHECKEDOUT rule to the view's config spec, then restart (or reload) the view.</P>

        </xsl:when>


        <xsl:when test="annotations[.='not loaded, checkedout but removed']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>To fix the checkdout but removed condition, cancel the checkout (click <STRONG>Tools &#8594; Undo Checkout</STRONG>) or restore the deleted file.</P>

        </xsl:when>


        <xsl:when test="annotations[.='not loaded']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>To load the element, click <STRONG>Edit View Properties</STRONG> on the Base ClearCase Tools tab, then edit the view's load rules. Or click <STRONG>Environment &#8594; Show Nonloaded Elements</STRONG> to suppress display of nonloaded elements. </P>

        </xsl:when>

<!-- No content yet for these conditions. Add as needed.


        <xsl:when test="annotations[.='no version selected']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is not selected by any config spec rule, or is selected by a -none config spec rule.</P>

        </xsl:when>


        <xsl:when test="annotations[.='error on reference']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is selected by an -error config spec rule.</P>

        </xsl:when>


        <xsl:when test="annotations[.='no config record ']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The derived object's data container is still stored in the view, but the derived object has been removed from the VOB.</P>

        </xsl:when>


        <xsl:when test="annotations[.='disputed checkout']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is considered to be checked out by the view server but is not so indicated in the VOB database.</P>

        </xsl:when>


        <xsl:when test="annotations[.='removed with white out']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The derived object was winked in by, and is still referenced by, the current view, but it has been removed from the VOB.</P>

        </xsl:when>


        <xsl:when test="annotations[.='overridden']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The element is loaded in the snapshot view, but its file type is not the same as the corresponding object in the VOB; or the element is not loaded in the snapshot view, but an object with the same name exists in the view.</P>

        </xsl:when>


        <xsl:when test="annotations[.='special selection']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The version you checked in is not the version that the config spec selects from the VOB.</P>

        </xsl:when>


        <xsl:when test="annotations[.='nocheckout']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The version hijacked in the view is no longer the version selected by the view's config spec.</P>

        </xsl:when>


        <xsl:when test="annotations[.='deleted version']">

                <P><EM STYLE="font-style: normal; font-weight: bold">Note: </EM>The version currently in the view has been removed from the VOB.</P>

        </xsl:when>
-->

        <xsl:otherwise>

        </xsl:otherwise>

    </xsl:choose>

</xsl:template>

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->

<!--     Procedures                                                                                 -->

<!-- +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->
<xsl:script><![CDATA[

function break_line(e) {

    var delim = ""

    var startstr = "";

    var endstr = e.text;

    var elen = endstr.length;

    if (endstr.indexOf("\\") != -1) {

        delim = "\\"

        }  else  {

        delim = "/"    

        }

    for (var i = 0; i > -1; elen = elen - i) {

        i = endstr.indexOf(delim,15);


        startstr = startstr.concat(endstr.substr(0,i+1) + "");

        endstr = endstr.substr(i+1);

    }

    return (startstr + endstr);

}        


function parent_dir(e,parentname) {

    if (e.text.indexOf(parentname) != '-1'){

        return 1;  

    }

    else{

        return 0;

    }

}        

]]>

</xsl:script>

</xsl:stylesheet>